Package: CompetingRisk
Type: Package
Title: The Semi-Parametric Cumulative Incidence Function
Version: 1.0
Date: 2017-02-25
Author: Jiayi Hou,
        Ronghui Xu
Maintainer: Jiayi Hou <jhou12@icloud.com>
Description: Computing the point estimator and pointwise confidence interval of the cumulative incidence function from the cause-specific hazards model.
Depends: survival, MASS, wesanderson, reshape2, stats, graphics,
        methods, Matrix
License: GPL-3
RoxygenNote: 6.0.1
NeedsCompilation: no
Packaged: 2017-03-02 03:49:43 UTC; jiayihou
Repository: CRAN
Date/Publication: 2017-03-02 08:09:10
