\name{Impute.Lambda}
\alias{Impute.Lambda}
\description{Impute.Lambda}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{
internal
}
\keyword{internal}% use one of  RShowDoc("KEYWORDS")

