\name{Impute.h}
\alias{Impute.h}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{
internal
}
\description{
impute.h
}
\usage{
Impute.h(x)
}
\keyword{internal}% use one of  RShowDoc("KEYWORDS")

